@@ -6,7 +6,10 @@
 #' @param ... Column(s) in \code{data}.
 #'
 #' @examples
+#' # all columns
 #' ds_auto_summary_stats(mtcarz)
+#'
+#' # multiple columns
 #' ds_auto_summary_stats(mtcarz, disp, hp)
 #'
 #' @export
@@ -19,7 +22,7 @@ ds_auto_summary_stats <- function(data, ...) {
 
   if (length(var) < 1) {
     if (!any(is_num == TRUE)) {
-      rlang::abort("Data has no continuous variables.")
+      stop("Data has no continuous variables.", call. = FALSE)
     }
     plot_data <- data[is_num]
   } else {
@@ -27,13 +30,13 @@ ds_auto_summary_stats <- function(data, ...) {
       dplyr::select(!!! var)
     is_num <- sapply(data, is.numeric)
     if (!any(is_num == TRUE)) {
-      rlang::abort("Data has no continuous variables.")
+      stop("Data has no continuous variables.", call. = FALSE)
     }
     plot_data <- data[is_num]
   }
 
   if (ncol(plot_data) < 1) {
-    rlang::abort("Data has no continuous variables.")
+    stop("Data has no continuous variables.", call. = FALSE)
   }
 
   num_var <- names(plot_data)
@@ -62,6 +65,7 @@ ds_auto_summary_stats <- function(data, ...) {
 #' @param ... Column(s) in \code{data}.
 #'
 #' @examples
+#' # summary statistics of mpg & disp for each level of cyl & gear
 #' ds_auto_group_summary(mtcarz, cyl, gear, mpg, disp)
 #'
 #' @export
@@ -76,10 +80,10 @@ ds_auto_group_summary <- function(data, ...) {
 
   if (length(var) < 1) {
     if (!any(is_factor == TRUE)) {
-      rlang::abort("Data has no categorical variables.")
+      stop("Data has no categorical variables.", call. = FALSE)
     }
     if (!any(is_num == TRUE)) {
-      rlang::abort("Data has no continuous variables.")
+      stop("Data has no continuous variables.", call. = FALSE)
     }
     plot_data  <- cbind(data[is_factor] , data[is_num] )
   } else {
@@ -87,19 +91,15 @@ ds_auto_group_summary <- function(data, ...) {
       dplyr::select(!!! var)
     is_num    <- sapply(data, is.numeric)
     if (!any(is_num == TRUE)) {
-      rlang::abort("Data has no continuous variables.")
+      stop("Data has no continuous variables.", call. = FALSE)
     }
     is_factor <- sapply(data, is.factor)
     if (!any(is_factor == TRUE)) {
-      rlang::abort("Data has no categorical variables.")
+      stop("Data has no categorical variables.", call. = FALSE)
     }
     plot_data <- cbind(data[is_factor], data[is_num])
   }
 
-  if (ncol(data) < 1) {
-    rlang::abort("Data should include at least one categorical and one continuous variable.")
-  }
-
   is_num    <- sapply(plot_data, is.numeric)
   is_factor <- sapply(plot_data, is.factor)
   num_data  <- plot_data[is_num]
