@@ -8,27 +8,22 @@ freq_table2.default <- function(data, name) {
     data %>%
     dplyr::select(name) %>%
     dplyr::pull(1) %>%
-    stats::na.omit()
+    na.omit()
 
   if (!is.factor(dat)) {
-    stop("data must be categorical/qualitative")
+    stop("Data must be categorical/qualitative.", call. = FALSE)
   }
 
+  cq          <- unique(sort(dat))
+  result      <- as.vector(table(dat))
   level_names <- levels(dat)
   data_len    <- length(dat)
-  cq          <- forcats::fct_unique(dat)
+  len         <- length(result)
+  cum         <- cumsum(result)
+  per         <- percent(result, data_len)
+  cum_per     <- percent(cum, data_len)
 
-  result <-
-    dat %>%
-    forcats::fct_count() %>%
-    dplyr::pull(2)
-
-  len     <- length(result)
-  cum     <- cumsum(result)
-  per     <- percent(result, data_len)
-  cum_per <- percent(cum, data_len)
-
-  ftable <- tibble::tibble(
+  ftable <- data.frame(
     Levels          = level_names,
     Frequency       = result,
     `Cum Frequency` = cum,
@@ -42,22 +37,25 @@ freq_table2.default <- function(data, name) {
     is.na() %>%
     sum()
 
-  if (na_count > 0) {
-    na_freq <-
-      data %>%
-      dplyr::pull(name) %>%
-      forcats::fct_count() %>%
-      dplyr::pull(n) %>%
-      dplyr::last()
-  } else {
-    na_freq <- 0
-  }
-
   n_obs <-
     data %>%
     dplyr::pull(name) %>%
     length()
 
+  if (na_count > 0) {
+    na_data <- dplyr::pull(data, var_name)
+
+    var_count <-
+      na_data %>%
+      table() %>%
+      as.vector() %>%
+      sum()
+
+    na_freq <- n_obs - var_count
+  } else {
+    na_freq <- 0
+  }
+
   result <- list(
     ftable   = ftable,
     varname  = var_name,
