@@ -1,5 +1,3 @@
-context("test-group-summary-interact")
-
 test_that("output from ds_group_summary_interact is as expected", {
   actual <-
     ds_group_summary_interact(mtcarz, mpg, cyl, gear) %>%
@@ -16,6 +14,13 @@ test_that("ds_group_summary_interact throws the appropriate error", {
     "am is not a continuous variable. The function expects an object of type `numeric` or `integer` but am is of type `factor`."
   )
 
+  expect_error(
+    ds_group_summary_interact(mtcarz, mpg, cyl, disp, hp),
+    "Below grouping variables are not categorical: 
+- disp
+- hp"
+  )
+
   expect_error(
     ds_group_summary_interact(mtcarz, mpg, cyl, hp),
     "Below grouping variables are not categorical: 
