@@ -1,9 +1,21 @@
-context("test-plots")
+ndata <- dplyr::select(mtcarz, mpg, disp)
+fdata <- dplyr::select(mtcarz, cyl, gear)
+mdata <- dplyr::select(mtcarz, cyl, mpg)
+
+test_that("output from ds_screener is as expected", {
+  x <- ds_screener(airquality)
+  p <- plot(x)
+  vdiffr::expect_doppelganger("ds_screener_1", p)
+})
 
 test_that("output from ds_plot_scatter is as expected", {
   p <- ds_plot_scatter(mtcarz, mpg, disp, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_scatter_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_scatter_2", p[[2]])
+
+  q <- ds_plot_scatter(ndata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_scatter_3", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_scatter_4", q[[2]])
 })
 
 test_that("output from ds_plot_histogram is as expected", {
@@ -11,43 +23,78 @@ test_that("output from ds_plot_histogram is as expected", {
   vdiffr::expect_doppelganger("ds_plot_hist_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_hist_2", p[[2]])
   vdiffr::expect_doppelganger("ds_plot_hist_3", p[[3]])
+
+  q <- ds_plot_histogram(ndata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_hist_4", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_hist_5", q[[2]])
 })
 
 test_that("output from ds_plot_density is as expected", {
+  # skip_if(getRversion() > '4.0.3')
   p <- ds_plot_density(mtcarz, mpg, disp, hp, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_density_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_density_2", p[[2]])
   vdiffr::expect_doppelganger("ds_plot_density_3", p[[3]])
+
+  q <- ds_plot_density(ndata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_density_4", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_density_5", q[[2]])
 })
 
 test_that("output from ds_plot_bar is as expected", {
   p <- ds_plot_bar(mtcarz, cyl, gear, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_bar_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_bar_2", p[[2]])
+
+  q <- ds_plot_bar(fdata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_bar_3", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_bar_4", q[[2]])
+
 })
 
 test_that("output from ds_plot_box_single is as expected", {
   p <- ds_plot_box_single(mtcarz, mpg, disp, hp, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_box_single_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_box_single_2", p[[2]])
+
+  q <- ds_plot_box_single(ndata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_box_single_3", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_box_single_4", q[[2]])
+  
 })
 
 test_that("output from ds_plot_bar_stacked is as expected", {
+
   p <- ds_plot_bar_stacked(mtcarz, cyl, gear, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_bar_stacked_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_bar_stacked_2", p[[2]])
+
+  q <- ds_plot_bar_stacked(fdata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_bar_stacked_3", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_bar_stacked_4", q[[2]])
 })
 
 test_that("output from ds_plot_bar_grouped is as expected", {
+
   p <- ds_plot_bar_grouped(mtcarz, cyl, gear, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_bar_grouped_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_bar_grouped_2", p[[2]])
+
+  q <- ds_plot_bar_grouped(fdata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_bar_grouped_3", q[[1]])
+  vdiffr::expect_doppelganger("ds_plot_bar_grouped_4", q[[2]])
+
 })
 
 test_that("output from ds_plot_box_group is as expected", {
+
   p <- ds_plot_box_group(mtcarz, cyl, gear, mpg, print_plot = FALSE)
   vdiffr::expect_doppelganger("ds_plot_box_group_1", p[[1]])
   vdiffr::expect_doppelganger("ds_plot_box_group_2", p[[2]])
+
+  q <- ds_plot_box_group(mdata, print_plot = FALSE)
+  vdiffr::expect_doppelganger("ds_plot_box_group_3", q[[1]])
+  
 })
 
 ndata <- dplyr::select(mtcarz, mpg, disp, hp, wt, qsec, drat)
